summaryrefslogtreecommitdiffstats
path: root/parts/appwizard/filepropspage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/appwizard/filepropspage.cpp')
-rw-r--r--parts/appwizard/filepropspage.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/parts/appwizard/filepropspage.cpp b/parts/appwizard/filepropspage.cpp
index e7436d04..1ec0b6df 100644
--- a/parts/appwizard/filepropspage.cpp
+++ b/parts/appwizard/filepropspage.cpp
@@ -7,11 +7,11 @@
#include <tqmultilineedit.h>
/*
* Constructs a FilePropsPage which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-FilePropsPage::FilePropsPage( TQWidget* parent, const char* name, WFlags fl )
- : FilePropsPageBase( parent, name, fl ){
+FilePropsPage::FilePropsPage( TQWidget* tqparent, const char* name, WFlags fl )
+ : FilePropsPageBase( tqparent, name, fl ){
m_props = new TQPtrList<ClassFileProp>;
m_current_class = 9999; // no current
}
@@ -21,7 +21,7 @@ FilePropsPage::FilePropsPage( TQWidget* parent, const char* name, WFlags fl )
*/
FilePropsPage::~FilePropsPage()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -7,11 +7,11 @@
#include <tqmultilineedit.h>
/*
- * Constructs a FilePropsPage which is a child of 'parent', with the
+ * Constructs a FilePropsPage which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/